This crate contains kube-rs compatible bindings for Kubernetes custom resources for the operator.victoriametrics.com group. Each binding is generated with kopium, updated and released weekly.
Available Custom Resources
operator.victoriametrics.com/v1
VLAgentVLClusterVLSingleVMAnomalyVMAnomalyConfigVTClusterVTSingle
operator.victoriametrics.com/v1alpha1
VMDistributed
operator.victoriametrics.com/v1beta1
VLogsVMAgentVMAlertmanagerConfigVMAlertmanagerVMAlertVMAuthVMClusterVMNodeScrapeVMPodScrapeVMProbeVMRuleVMScrapeConfigVMServiceScrapeVMSingleVMStaticScrapeVMUser